# ESBMC AI

AI Augmented ESBMC processing. Passes the output from ESBMC to an AI model that allows the user to use natural language to understand the output. As the output from ESBMC can be quite technical in nature. The AI can also be asked other questions, such as suggestions on how to fix the problem outputted by ESBMC, and to offer further explanations.

This is an area of active research.

![ESBMC-AI Visual Abstract](https://github.com/Yiannis128/esbmc-ai/assets/9535618/1b51c57f-a769-4067-abd9-e81de5e7506b)

## Demonstration

[![Fix Code Demo](https://img.youtube.com/vi/anpRa6GpVdU/0.jpg)](https://www.youtube.com/watch?v=anpRa6GpVdU)

More videos can be found on the [ESBMC-AI Youtube Channel](https://www.youtube.com/@esbmc-ai)

## Wiki (Initial Setup/Configuration/Usage)

For full documentation, see the [ESBMC-AI Wiki](https://github.com/Yiannis128/esbmc-ai/wiki). The README file contains quick setup instructions, however it is recommended to read the following two pages, to fully guide you on how to download, set-up and run ESBMC-AI.

* [Initial Setup Wiki Page](https://github.com/Yiannis128/esbmc-ai/wiki/Initial-Setup).
* [Configuration Wiki Page](https://github.com/Yiannis128/esbmc-ai/wiki/Configuration).
* [Usage Wiki Page](https://github.com/Yiannis128/esbmc-ai/wiki/Initial-Setup#usage).

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

1. Keep the coding style consistent. Use the [Black](https://pypi.org/project/black/) code formatter.
2. Keep the righting style professional.
3. Include comments and function doc-strings.
4. Make sure to update tests as appropriate.

## Acknowledgments

ESBMC-AI is made possible by the following listed entities:

- [ESBMC](https://github.com/esbmc/esbmc)
- [OpenAI Chat API](https://platform.openai.com/docs/guides/chat)
- [Technology Innovation Institute](https://www.tii.ae/)
- [Hugging Face](https://huggingface.co/)
- [Langchain](https://github.com/langchain-ai/langchain)

## License

[GNU Affero General Public License v3.0](https://github.com/Yiannis128/esbmc-ai/blob/master/LICENSE)
